@@ -3,7 +3,21 @@ define('oxguard/mail/maillist', ['io.ox/mail/common-extensions', 'io.ox/core/ext
     'use strict';
     
     var lockclass = 'icon-lock icon-2x fa fa-lock fa-2x oxguard_icon_fa';
+    var initialized = false;
    
+    // Changed selection.  Null out the guard current data
+    function change () {
+        window.oxguarddata.current = null;
+    }
+        
+    // To initialize listview.  Setup here
+    function listViewInit() {
+        require (['io.ox/mail/main'], function (main) {
+            var app = main.getApp();
+            app.listView.on('selection:change', change);
+        });
+    }
+    
     
     // Disable default paper clip, as all oxguard emails have attachments.  Will call manually.
     ext.point('io.ox/mail/listview/item/default/row2').disable('paper-clip');
@@ -17,6 +31,7 @@ define('oxguard/mail/maillist', ['io.ox/mail/common-extensions', 'io.ox/core/ext
             addLock.call(this, baton);
         }
     });
+    
     // Extension point for List view, change in 7.6.1   
     if (ox.serverConfig.version.indexOf('7.6.0') === 0) {
         ext.point('io.ox/mail/listview/item/small/col4').extend({
@@ -42,6 +57,10 @@ define('oxguard/mail/maillist', ['io.ox/mail/common-extensions', 'io.ox/core/ext
     // Check if OxGuard email, and if so, add lock icon.  Add paperclip if applicable
     function addLock(baton) {
         try {
+            if (!initialized) {
+                listViewInit();
+                initialized = true;
+            }
             if (baton.data.attachment === undefined) {
                 return;
             }
@@ -54,11 +73,44 @@ define('oxguard/mail/maillist', ['io.ox/mail/common-extensions', 'io.ox/core/ext
                 extensions.paperClip.call(this, baton);
                 return;
             }
+            var attachments = baton.model.get('attachments');
+            /// PGP Components
+            // Check if decoded
+            if (baton.model.get('PGPDecoded') === true) {
+                this.append($('<i class="' + lockclass + '" aria-hidden="true">'));
+                if (baton.model.get('attachment') === true) {
+                    extensions.paperClip.call(this, baton);
+                }
+                return;
+            }
+            // Check if not yet decoded PGP
+            for (var i = 0; i < attachments.length; i++) {// check for attachments
+                try {
+                    if (attachments[i].content_type !== null) {
+                        if (attachments[i].content_type.indexOf('pgp-encrypted') > 0) {
+                            this.append($('<i class="' + lockclass + '" aria-hidden="true">'));
+                            return;
+                        }
+                        if (attachments[i].content_type.indexOf('text') > -1) {
+                            if (attachments[i].content !== null) {
+                                if (attachments[i].content.indexOf('----BEGIN PGP') > 0) {
+                                    this.append($('<i class="' + lockclass + '" aria-hidden="true">'));
+                                    extensions.paperClip.call(this, baton);
+                                    return;
+                                }
+                            }
+                        }
+                    }
+                } catch (e) {
+                    console.log('error getting content type of attachment ', e);
+                }
+            }
+            // Proprietary Guard components
             if (headers['X-OxGuard-ID'] !== undefined) {
                 baton.data.og = true;
                 baton.model.set('og', true);
                 this.append($('<i class="' + lockclass + '" aria-hidden="true">'));
-                var attachments = baton.model.get('attachments');
+                
                 if (attachments === undefined) {
                     return;
                 }
