@@ -18,6 +18,11 @@ define('oxguard/mail/register_mail', ['io.ox/core/extensions',
     var popupBlockCount = 0;
     var unified_sent = null;
     
+    if (window.oxguarddata.oldcompose) {
+        require(['oxguard/mail/register_oldcompose']);
+    } else 
+        require(['oxguard/mail/mail_extensions_compose']);
+    
     ///////////////////  Email points
     ext.point('io.ox/mail/attachment/links').extend(new links.Link({
         id: 'OGSave',
@@ -26,120 +31,7 @@ define('oxguard/mail/register_mail', ['io.ox/core/extensions',
         ref: 'io.ox/mail/actions/save-OGattachment'
     }));
     
-    ////////  Reply or Reply all actions from top command bar
-    
-    // If secure Reply, we need to update the reply email with the decrypted text, and format
-    ext.point('io.ox/mail/write/initializers/before').extend({
-        modify: function (baton) {
-            try {
-                if (window.oxguarddata.action === 'secureReply') {
-                    if (baton.mail.format === 'text') {
-                        baton.mail.data.attachments[0].content = prepareTextReply($.extend({}, window.oxguarddata.temp));
-                        baton.mail.data.attachments[0].content_type = 'text/plain'; 
-                    } else {
-                        baton.mail.data.attachments[0].content = prepareReply($.extend({}, window.oxguarddata.temp));
-                        baton.mail.data.attachments[0].content_type = 'text/html'; 
-                    }
-           
-                } else {
-                    if (baton.mail.data.headers === undefined) return;
-                    if (baton.mail.data.headers['In-Reply-To'] !== undefined) {
-                        if (baton.mail.data.headers['In-Reply-To'].indexOf('OxGuard') > 0) baton.mail.data.attachments[0].content = '';
-                    }
-                }
-                if (window.oxguarddata.actionType === 'replyAll') {
-                    addTo(baton);
-                }
-                require (['oxguard/mail/options'], function () {  // Make sure the options javascript has had a chance to load
-                    window.setTimeout(function () {
-                        window.oxguarddata.action = '';// reset action
-                        window.oxguarddata.actionType = '';
-                    }, 100);
-                });
-                
-            } catch (e) {
-                console.log('Error writing to editor with reply');
-                console.log(e);
-            }
-        }
-    });
-    
-    
-    // For replyAll, we need to add back all the recipients from decrypted email
-    function addTo (baton) {
-        var to = window.oxguarddata.temp.to;
-        var newto = [];
-        var user = baton.app.getView().form.find('.sender-dropdown').val();// Get current users email
-        for (var i = 0; i < to.length; i++) {
-            if (user.indexOf(to[i][1]) < 0) { // dont add the user to recip list
-                newto.push(to[i]);
-            }
-        }
-        baton.app.setTo(newto);
-        baton.app.setCC(window.oxguarddata.temp.cc);
-    }
 
-    // When hitting reply, see if was a secured email.  If so, set temp vars for updating reply email
-    ext.point('io.ox/mail/actions/reply').extend({
-        index: 1,
-        id: 'securedreply',
-        action: function () {
-            if (window.oxguarddata.temp === null) return;
-            if (window.oxguarddata.temp.og === true) {
-                window.oxguarddata.action = 'secureReply';
-                window.oxguarddata.actionType = 'reply';
-            }
-        }
-    });
-    
-    ext.point('io.ox/mail/actions/forward').replace({
-        id: 'forward',
-        requires: function (e) {
-            try {
-                var data = e.baton.isThread ? e.baton.first() : e.baton.data;
-                if (data === undefined) return e.collection.has('toplevel', 'some');
-                if (data.headers !== undefined) { // Email selected
-                    if (data.headers['X-OxGuard'] !== undefined) { // Will not be defined if sent from other client
-                        if (data.headers['X-OxGuard'].toLowerCase() === 'true')  // Will be defined but false from UI
-                            return false;
-                    }
-                }
-            } catch (e) {
-                console.log('catch in forward require');
-                console.log(e);
-            }
-            return e.collection.has('toplevel', 'some');
-        },
-        action: function (baton) {
-
-            var data = baton.isThread ? baton.first() : baton.data;
-            if (ox.registry === undefined) {
-                require(['io.ox/mail/write/main'], function (m) {
-                    if (m.reuse('forward', data)) return;
-                    m.getApp().launch().done(function () {
-                        this.forward(data);
-                    });
-                });
-            } else {
-                ox.registry.call('mail-compose', 'forward', data);
-            }
-            
-        }
-    });
-    
-    
-    // Check if secured email.  
-    ext.point('io.ox/mail/actions/reply-all').extend({
-        index: 1,
-        id: 'securedreplyall',
-        action: function () {
-            if (window.oxguarddata.temp === null) return;
-            if (window.oxguarddata.temp.og === true) {
-                window.oxguarddata.action = 'secureReply';
-                window.oxguarddata.actionType = 'replyAll';
-            }
-        }
-    });
 
     
     /////////  Extension points reader / inbox
@@ -278,6 +170,8 @@ define('oxguard/mail/register_mail', ['io.ox/core/extensions',
         }
     });
     
+
+    
     // Save decrypted attachment.  Need to add the .oxg suffix
     new links.Action('io.ox/mail/actions/save-OGdecoded', {
         id: 'SaveOG',
@@ -318,6 +212,8 @@ define('oxguard/mail/register_mail', ['io.ox/core/extensions',
     
 
     
+
+    
     
     
     // For attachments, need to change links to decoding through oxguard if encrypted.
@@ -330,7 +226,7 @@ define('oxguard/mail/register_mail', ['io.ox/core/extensions',
     });
     
     function setAttachments(baton) {
-        regAttach();    // Default is to just display the regular links
+        regAttach(baton);    // Default is to just display the regular links
         if (baton.data.headers === undefined) return;   // Usually not defined unless decrypted email
         if (baton.data.attachments === undefined) return;
         if (baton.data.headers['X-OxGuard'] === undefined) return;
@@ -342,7 +238,7 @@ define('oxguard/mail/register_mail', ['io.ox/core/extensions',
             // We are going to search the attachments, and not display the main email attachment if present
             try {
                 if (baton.data.attachment) {
-                    ogAttach();
+                    ogAttach(baton);
                 } else {// If no attachments to show, hide the attachment div
                     baton.view.$el.find('.attachments').remove();
                 }
@@ -356,9 +252,10 @@ define('oxguard/mail/register_mail', ['io.ox/core/extensions',
         }
     }
     
-    function ogAttach() {
+    function ogAttach(baton) {
         // Set the right links in the attachment dropdown
    //     ext.point('io.ox/mail/attachment/links').disable('preview');
+        baton.data.og = true;
         ext.point('io.ox/mail/attachment/links').disable('download');
         ext.point('io.ox/mail/attachment/links').disable('save');
         ext.point('io.ox/mail/attachment/links').disable('open');
@@ -374,22 +271,25 @@ define('oxguard/mail/register_mail', ['io.ox/core/extensions',
         ext.point('io.ox/mail/attachment/links').disable('office_view');
     }
     
-    function regAttach() {
-        ext.point('io.ox/mail/detail/attachments').enable('attachment-list');
-        ext.point('io.ox/mail/attachment/links').enable('preview');
-        ext.point('io.ox/mail/attachment/links').enable('download');
-        ext.point('io.ox/mail/attachment/links').enable('save');
-        ext.point('io.ox/mail/attachment/links').enable('open');
-        ext.point('io.ox/mail/attachment/links').enable('vcard');
-        ext.point('io.ox/mail/attachment/links').enable('ical');
-        ext.point('io.ox/mail/attachment/links').enable('slideshow');
+    function regAttach(baton) {
         ext.point('io.ox/mail/attachment/links').disable('OGopen');
         ext.point('io.ox/mail/attachment/links').disable('OGdownload');
         ext.point('io.ox/mail/attachment/links').disable('OGSave');
         ext.point('io.ox/mail/attachment/links').disable('OGsaveDecoded');
-        ext.point('io.ox/mail/attachment/links').enable('text_edit');
-        ext.point('io.ox/mail/attachment/links').enable('spreadsheet_edit');
-        ext.point('io.ox/mail/attachment/links').enable('office_view');
+        if (!baton.data.PGP) {  // If not PGP email, then re-enable links
+            ext.point('io.ox/mail/detail/attachments').enable('attachment-list');
+            ext.point('io.ox/mail/attachment/links').enable('preview');
+            ext.point('io.ox/mail/attachment/links').enable('download');
+            ext.point('io.ox/mail/attachment/links').enable('save');
+            ext.point('io.ox/mail/attachment/links').enable('open');
+            ext.point('io.ox/mail/attachment/links').enable('vcard');
+            ext.point('io.ox/mail/attachment/links').enable('ical');
+            ext.point('io.ox/mail/attachment/links').enable('slideshow');
+            ext.point('io.ox/mail/attachment/links').enable('text_edit');
+            ext.point('io.ox/mail/attachment/links').enable('spreadsheet_edit');
+            ext.point('io.ox/mail/attachment/links').enable('office_view');
+        }
+
     }
     
     // Add lock to header
@@ -489,321 +389,9 @@ define('oxguard/mail/register_mail', ['io.ox/core/extensions',
     }
     
     
-    ///////////////  Write / Send
-    
-    // Set the action for send.
-    var sendpoint = ext.point('io.ox/mail/write/actions/send');
-    sendpoint.replace({
-        id: 'default',
-      //  index: 'default',
-        action: function (baton) {
-            var view = baton.app.getView().form;
-            if (view.find('#OxGuardOn').is(':checked')) {
-                if (window.oxguarddata.passcode === 'No Key') {
-                    require (['oxguard/mail/oxguard_mail_write_core'], function (core) {
-                        core.createKeys('', view);
-                    });
-                    return;// Do not send until the master key is created
-                }
-                require (['oxguard/mail/sender'], function (sender) {
-                    sender.sendMail(baton, window.oxguarddata.passcode);
-                });
-                
-            } else {
-                baton.app.send();
-            }
-            
-        }
-    });
-    
-    
-    var sendpoint = ext.point('io.ox/mail/write/actions/draft');
-    sendpoint.replace({
-        id: 'default',
-      //  index: 'default',
-        action: function (baton) {
-            if (baton.app.isSaving === true) return;
-            baton.app.isSaving = true;
-            var view = baton.app.getView().form;
-            if (view.find('#OxGuardOn').is(':checked')) {
-                if (window.oxguarddata.passcode === 'No Key') {
-                    require (['oxguard/mail/oxguard_mail_write_core'], function (core) {
-                        core.createKeys('', view);
-                    });
-                    baton.app.isSaving = false;
-                    return;// Do not send until the master key is created
-                }
-                require (['oxguard/mail/sender'], function (sender) {
-                    sender.draftMail(baton, window.oxguarddata.passcode);
-                });
-                
-            } else {
-                baton.app.saveDraft()
-                    .done(function (data) {
-                        baton.app.refId = data.msgref;
-                        baton.app.isSaving = false;
-                    }).fail(function () {
-                        baton.app.isSaving = false;
-                    });
-            }
-            
-        }
-    });
-
-    //  Edit a guard draft email
-    var editpoint = ext.point('io.ox/mail/actions/edit');
-    editpoint.replace ({
-        id: 'edit',
-        requires: function (e) {
-            // must be top-level
-            if (!e.collection.has('toplevel')) return;
-            // multiple and not a thread?
-            if (!e.collection.has('one') && !e.baton.isThread) return;
-            // get first mail
-            var data = e.baton.first();
-            // must be draft folder
-            return data && isDraftMail(data);
-        },
-        action: function (baton) {
-            var data = baton.first(),
-                check = false;
-            _.each(ox.ui.apps.models, function (app) {
-                if (app.refId === data.id) {
-                    check = true;
-                    app.launch();
-                }
-            });
-            if (check === true) return;
-            try {
-                if (data.headers['X-OxGuard'] !== undefined) {
-                    if (window.oxguarddata.temp !== null) {
-                        window.oxguarddata.temp.ogId = undefined;  // Not replying to an email, null out
-                        require(['io.ox/mail/write/main', 'oxguard/mail/oxguard_mail_write_core'], function (m, core) {
-                            m.getApp().launch().done(function () {
-                                this.compose({ folder_id: baton.app.folder.get() });
-                                var view = this.getView().form;
-                                var header = window.oxguarddata.temp.headers;
-                                this.setMail(prepareDraft(window.oxguarddata.temp))
-                                .done(function () {
-                                    if (header['X-OxGuard-ExtraPass'].trim() !== '') {
-                                        view.find('#passbox').val(header['X-OxGuard-ExtraPass']);
-                                        view.find('#reqpassword').prop('checked', 'true');
-                                        view.find('#passbox').parent().show();
-                                    }
-                                    view.find('#expdatepicker').val(header['X-OxGuard-Expiration']);
-                                    core.saveToHeader(view);
-                                });
-                            });
-                        });
-                        return;
-                    }
-                    
-                }
-            } catch (e) {
-                console.log(e);
-            }
-            require(['io.ox/mail/write/main'], function (m) {
-                if (m.reuse('edit', data)) return;
-                m.getApp().launch().done(function () {
-                    this.edit(data);
-                });
-            });
-           // ox.registry.call('mail-compose', 'edit', data);
-        }
-    });
-    
-    function prepareDraft (dat) {
-        var ordered = $.parseJSON(JSON.stringify(dat));
-        ordered.attachments = [];
-        ordered.headers = {};  // Remove most headers as was just draft email
-        ordered.headers['X-OxGuard-ExtraPass'] = dat.headers['X-OxGuard-ExtraPass'];
-        ordered.headers['X-OxGuard'] = dat.headers['X-OxGuard'];
-        ordered.headers['X-OxGuard-Expiration'] = dat.headers['X-OxGuard-Expiration'];
-        ordered.msgref = ordered.folder_id + '/' + ordered.id;
-        var attachments = dat.attachments;
-        var added = -1;
-        // Attachments must be re-ordered, so the inline is first.
-        for (var i = 0; i < attachments.length; i++) {
-            if (attachments[i].disp === 'inline') {
-               ordered.attachments.push(attachments[i]); 
-               added = i;
-            }
-        }
-        for (i = 0; i < attachments.length; i++) {
-            if (i !== added) ordered.attachments.push(attachments[i]);
-        }
-        var newdata = {
-                data : ordered,
-                format : 'html'
-        };
-        return (newdata);
-    }
  
-    var isDraftFolder = function (folder_id) {
-        return _.contains(account.getFoldersByType('drafts'), folder_id);
-    },
-    isDraftMail = function (mail) {
-        return isDraftFolder(mail.folder_id) || ((mail.flags & 4) > 0);
-    };
     
-    // Email writing
-    
-    // Add the oxguard button to write toolbar
-    
-    
-    ext.point('io.ox/mail/write/filelist/filePicker/customizer').extend({
-        id: 'oxguard',
-        customize: function (file) {
-            if (file.filename.indexOf('.grd') > 0) {
-              //  var newfilename = file.filename.replace('.grd2', '').replace('.grd', '');
-                var icon = '<i class = "fa fa-lock oxguard_lock_p"/>';
-                $(this).find('.name').text(file.filename).prepend(icon);
-            }
-        }
-    });
-
-    
-    var newpoint = ext.point('io.ox/mail/write/toolbar');
-    newpoint.extend({
-        id: 'locksend',
-        index: 100,
-        draw: function (baton) {
-            // Create Security Link
-            try {
-                if ($('.btn-primary:visible').length === 0) return;// if page not yet created
-                if ($('.btn-primary:visible').prev().is('[name="Page"]')) {//We've already updated this
-                    return;
-                }
-                var view = baton.app.getView().form;
-                if (view === undefined) return;//View not yet loaded
-                if (view.find('#OxGuardOn').length > 0) return;//Already created
-                require (['oxguard/mail/options'], function (options) {
-                    options.createOptions(view, baton);
-                });
-                addBlur('#writer_field_to', view);
-                addBlur('#writer_field_cc', view);
-                addBlur('#writer_field_bcc', view);
-                
-            } catch (e) {
-                console.log(e.toString());
-            }
-            
-        }
-        
-    });
-    
-    function addBlur(id, view) {
-        $(id).blur(function () {
-            if (view.find('#OxGuardOn').is(':checked')) {
-                window.setTimeout(function () {
-                    require (['oxguard/mail/oxguard_mail_write_core'], function (core) {
-                        core.checkRecip(view);
-                    });
-                }, 200);
-            }
-        }).keypress(function(e) {
-            if (e.which === 13) {
-                if (view.find('#OxGuardOn').is(':checked')) {
-                    window.setTimeout(function () {
-                        require (['oxguard/mail/oxguard_mail_write_core'], function (core) {
-                            core.checkRecip(view);
-                        });
-                    }, 200);
-                }
-            }
-        });
-    }
-    
-    ext.point('io.ox/mail/write/filelist/file/customizer').extend({
-        id: 'oxguardfilelist',
-        customize: function (e) {
-            var icon = '<i class = "fa fa-lock oxguard_lock_p"/>';
-            if (e.file.epass !== undefined) {
-                $(this).find('.attachment-preview').hide();
-            }
-            $(this).find('.row-1').each(function (e, v) {
-                var te = $(v);
-                if (te.text().indexOf('.grd') > 0) {
-                    te.html(icon + te.text());
-                    $('#statuslock.icon-unlock:visible').click();// Enable encryption if not set
-                }
-            });
-        }
-    });
-    
-    
-    // Format an email for reply
-    function prepareReply(tmp) {
-        try {
-            if (tmp === null) return ('');
-            if (tmp.replytext === undefined) return ('');
-            var sentDate = new Date(tmp.received_date);
-            var from = ' ' + tmp.replyfrom[0][0] + ' ';
-            //#. Used for top of reply email, %1 is date, %2 is name
-            //#. Would appear like - On 4/5/14 12:30 Greg sent:
-            var line = ' ' + gt('On %1$s %2$s sent:', sentDate.toLocaleString(), from);
-            if (tmp.replytype === undefined) tmp.replytype = '';
-            var header = '';
-            if (tmp.replytype.indexOf('html') > 0) {
-                header = '<br/><blockquote type="cite"><span>' + line + '</span><br/>' + tmp.replytext + '</blockquote>';
-              //  header = '<br/><div style="border-left: 1px solid blue; padding-left:10px;"><span>' + line + '</span><br/>' + tmp.replytext + '</div>';
-            } else {
-                header = '\r\n\r\n---------------------------------------\r\n' + line + '\r\n' + tmp.replytext;
-            }
-            return (header);
-        } catch (e) {
-            console.log(e);
-            return (header);
-        }
-    }
-
-    // Generate Plaintext email reply
-    function prepareTextReply (tmp) {
-        try {
-            if (tmp === null) return ('');
-            if (tmp.replytext === undefined) return ('');
-            var sentDate = new Date(tmp.received_date);
-            var from = ' ' + tmp.replyfrom[0][0] + ' ';
-            var line = ' ' + gt('On %1$s %2$s sent:', sentDate.toLocaleString(), from);
-            if (tmp.replytype === undefined) tmp.replytype = '';
-            tmp.replytext = convertHTML(tmp.replytext);
-            var header = '\n>' + line + '\n' + tmp.replytext + '\n';
-            return (header);
-        } catch (e) {
-            console.log(e);
-            return (header);
-        }
-    }
-    
-    // Convert HTML email to plaintext
-    function convert (html, start) {
-        try {
-            if (start === undefined)
-                start = 0;
-            var i = html.indexOf('<blockquote', start);
-            if (i > -1) {
-                i = html.indexOf('>', i) + 1;
-                html = convert(html, i);
-            }
-            var j = html.indexOf('</blockquote');
-            var substring = html.substring(start);
-            if (j > -1) {
-                substring = html.substring(start, j);
-            } 
-            var newstring = '> ' + substring.replace(/\n/g, '\n> ').replace(/<br[\/]*>/gi, '\n> ')
-                    .replace(/<p[\/]*>/gi, '\n> ').replace(/<blockquote[^>]*>/,'\n> ').replace(/<(?:.|\s)*?>/g, '') + '\n> ';
-            html = html.replace(substring, newstring);
-            return (html);
-        } catch (e) {
-            console.log(e);
-            return (html);
-        }
-    }
-    
-    function convertHTML(html) {
-        return (convert(html, 0).replace(/<blockquote[^>]*>/,'\n> ').replace(/<(?:.|\s)*?>/g, ''));
-    }
-
+ 
 
     ////////////////  Status in sent folder
     
@@ -818,12 +406,12 @@ define('oxguard/mail/register_mail', ['io.ox/core/extensions',
     new links.Action('io.ox/mail/actions/status', {
         id: 'statusaction',
         requires: function (e) {
-            console.log(unified_sent);
             if (!(_.contains(account.getFoldersByType('sent'), e.context.folder_id)) && (e.context.folder_id !== unified_sent)) return(false);
             try {
                 if (e.baton.data.headers === undefined) return(false);
+                if (e.baton.data.headers['X-OxGuard'] === undefined) return(false);
                // return((e.baton.data.headers['X-OxGuard'].toLowerCase() === 'true') && e.baton.data.decoded);
-                return((e.baton.data.headers['X-OxGuard'].toLowerCase() === 'true') && (window.oxguarddata.temp!==null));
+                return((e.baton.data.headers['X-OxGuard'].toLowerCase() === 'true') && (window.oxguarddata.current!==null));
             } catch (ex) {
                 console.log(ex);
                 return (false);
@@ -840,7 +428,7 @@ define('oxguard/mail/register_mail', ['io.ox/core/extensions',
             if (!(_.contains(account.getFoldersByType('sent'), e.context.folder_id)) && (e.context.folder_id !== unified_sent)) return(false);
             try {
                 if (e.baton.data.headers === undefined) return(false);
-                return((e.baton.data.headers['X-OxGuard-PIN'] !== undefined) && e.baton.data.decoded);
+                return(e.baton.data.headers['X-OxGuard-PIN'] !== undefined);
             } catch (ex) {
                 console.log(ex);
                 return (false);
@@ -864,7 +452,7 @@ define('oxguard/mail/register_mail', ['io.ox/core/extensions',
         index: 101,
         prio: 'lo',
         id: 'pinlink',
-        label: gt('PIN'),
+        label: gt('Check assigned PIN'),
         ref: 'io.ox/mail/actions/pin',
         mobile: 'lo'
     }));
@@ -880,6 +468,110 @@ define('oxguard/mail/register_mail', ['io.ox/core/extensions',
         });
     }
     
+    //  Edit a guard draft email
+    var editpoint = ext.point('io.ox/mail/actions/edit');
+    editpoint.replace ({
+        id: 'edit',
+        requires: function (e) {
+            // must be top-level
+            if (!e.collection.has('toplevel')) return;
+            // multiple and not a thread?
+            if (!e.collection.has('one') && !e.baton.isThread) return;
+            // get first mail
+            var data = e.baton.first();
+            // If PGP email and not decoded, then hide edit button
+            if (e.baton.data.pgp_found === true && e.baton.data.PGPDecoded !== true) return;
+            // must be draft folder
+            return data && isDraftMail(data);
+        },
+        action: function (baton) {
+            var data = baton.first(),
+                check = false;
+            _.each(ox.ui.apps.models, function (app) {
+                if (app.refId === data.id) {
+                    check = true;
+                    app.launch();
+                }
+            });
+            if (check === true) return;
+            try {
+                    if (window.oxguarddata.current !== null) {
+                        window.oxguarddata.current.ogId = undefined;  // Not replying to an email, null out
+                        if (window.oxguarddata.oldcompose) {
+                            require(['io.ox/mail/write/main', 'oxguard/mail/oxguard_mail_write_core'], function (m, core) {
+                                m.getApp().launch().done(function () {
+                                    this.compose({ folder_id: baton.app.folder.get() });
+                                    var view = this.getView().form;
+                                    this.setMail(prepareDraft(window.oxguarddata.current))
+                                    .done(function () {
+                                        core.saveToHeader(view);
+                                    });
+                                });
+                            });
+                        } else {
+                            ox.registry.call('mail-compose', 'forward', prepareDraft(window.oxguarddata.current).data);
+                        }
+
+                        return;
+                    }
+            } catch (e) {
+                console.log(e);
+            }
+            if (window.oxguarddata.oldcompose) {
+                require(['io.ox/mail/write/main'], function (m) {
+                    if (m.reuse('edit', data)) return;
+                    m.getApp().launch().done(function () {
+                        this.edit(data);
+                    });
+                });
+            } else {
+                require(['io.ox/mail/compose/main'], function (m) {
+                    if (m.reuse('edit', data)) return;
+                    m.getApp().launch().done(function () {
+                        this.edit(data);
+                    });
+                });
+            }
+            
+        }
+    });
+    
+    function prepareDraft (dat) {
+        var ordered = $.parseJSON(JSON.stringify(dat));
+        ordered.attachments = [];
+        ordered.msgref = ordered.folder_id + '/' + ordered.id;
+        var attachments = dat.attachments;
+        var added = -1;
+        // Attachments must be re-ordered, so the inline is first.
+        for (var i = 0; i < attachments.length; i++) {
+            if (attachments[i].disp === 'inline') {
+               ordered.attachments.push(attachments[i]); 
+               added = i;
+            }
+        }
+        for (i = 0; i < attachments.length; i++) {
+            if (i !== added) {
+                var att = attachments[i];
+                att.group = 'attachment';
+                att.raw = true;
+                ordered.attachments.push(att);
+            }
+        }
+        var newdata = {
+                data : ordered,
+                format : 'html'
+        };
+        return (newdata);
+    }
+ 
+    var isDraftFolder = function (folder_id) {
+        return _.contains(account.getFoldersByType('drafts'), folder_id);
+    },
+    isDraftMail = function (mail) {
+        return isDraftFolder(mail.folder_id) || ((mail.flags & 4) > 0);
+    };
+    
+    
     // Get the status of emails
     function status(baton, retr) {
         require (['io.ox/core/tk/dialogs'], function (dialogs) {
@@ -972,7 +664,8 @@ define('oxguard/mail/register_mail', ['io.ox/core/extensions',
     }
 
     return {
-        status : status
+        status : status,
+        prepareDraft : prepareDraft 
     };
     
 });
