@@ -16,56 +16,65 @@ define('oxguard/register', ['io.ox/core/extensions', 'oxguard/oxguard_core',
     var oxguarddata = {
             passcode : null,
             settings:  {},
-
-            version: '1.2.0-4'
+          //  oldcompose : (ox.version.indexOf('7.6.') > -1),
+            oldcompose: true, // mark oldcompose always true for this version
+            version: '2.0.0-2626'
 
         };
     window.oxguarddata = oxguarddata;
     
     // Login section
-    sendauth('');
+    sendauth(''); // initial login, no password yet
+    
     
    
     function sendauth(pass)
     {
         oxguard.auth(ox.user_id, pass)
         .done(function (data) {
-            if (data.auth.length > 20) {// If good code comes back, then store userid
-                oxguarddata.userid = ox.user_id;
-                oxguarddata.passcode = data.auth;
-                $('.og_signout').show();
-            } else {// If bad code, then log and mark oxguard.user_id as -1
-                if ((data.auth.indexOf('Bad') > -1) || (data.auth.indexOf('Lockout') > -1)) {
-                    oxguarddata.passcode = null;
-                } else {
+            try {
+                if (data.auth.length > 20) {// If good code comes back, then store userid
+                    oxguarddata.userid = ox.user_id;
                     oxguarddata.passcode = data.auth;
-                }
-                oxguarddata.userid = -1;
-            }
-            if (ox.context_id === 0) ox.context_id = data.cid; // If the cid wasn't loaded, update from backend
-            oxguarddata.settings = data.settings; // user settings
-            oxguarddata.lang = data.lang;// Languages available
-            oxguarddata.server = data.server;
-            oxguarddata.baton = window.oxguarddata.baton;
-            oxguarddata.pubkey = data.pubKey;
-            window.oxguarddata = oxguarddata;
-            if (window.oxguarddata.baton !== undefined) {
-                require(['oxguard/register_mail'], function (mail) {
-                    mail.checkOG(window.oxguarddata.baton);
-                });
-                window.oxguarddata.baton = undefined;
-            }
-            if (sessionStorage !== null) {// If we were passed login info from login screen
-                try {
-                    if (sessionStorage.oxguard && (sessionStorage.oxguard !== 'null')) {
-                        var p = sessionStorage.oxguard;
-                        sessionStorage.oxguard = null;
-                        sendauth(p);
+                    $('.og_signout').show();
+                } else {// If bad code, then log and mark oxguard.user_id as -1
+                    if ((data.auth.indexOf('Bad') > -1) || (data.auth.indexOf('Lockout') > -1)) {
+                        oxguarddata.passcode = null;
+                    } else {
+                        oxguarddata.passcode = data.auth;
                     }
-                } catch (e) {
-                    console.log('Private mode');
-                    return;
+                    oxguarddata.userid = -1;
                 }
+                if (ox.context_id === 0) ox.context_id = data.cid; // If the cid wasn't loaded, update from backend
+                oxguarddata.settings = data.settings; // user settings
+                oxguarddata.lang = data.lang;// Languages available
+                oxguarddata.server = data.server;
+                oxguarddata.baton = window.oxguarddata.baton;
+                oxguarddata.pubkey = data.pubKey;
+                oxguarddata.recovery = data.recoveryAvail;
+                window.oxguarddata = oxguarddata;
+                
+                if (window.oxguarddata.baton !== undefined) {
+                    require(['oxguard/register_mail'], function (mail) {
+                        mail.checkOG(window.oxguarddata.baton);
+                    });
+                    window.oxguarddata.baton = undefined;
+                }
+                if (sessionStorage !== null) {// If we were passed login info from login screen
+                    try {
+                        if (sessionStorage.oxguard && (sessionStorage.oxguard !== 'null')) {
+                            var p = sessionStorage.oxguard;
+                            sessionStorage.oxguard = null;
+                            sendauth(p);
+                        }
+                    } catch (e) {
+                        console.log('Private mode');
+                        return;
+                    }
+                }
+            } catch (e) {
+                console.log(e);
+                console.debug('Unable to connect to the encryption server');
             }
         })
         .fail(function () {
@@ -78,7 +87,8 @@ define('oxguard/register', ['io.ox/core/extensions', 'oxguard/oxguard_core',
         id: 'logoutOG',
         logout: function () {
             // force save requests for all pending settings
-            $.get(ox.apiRoot + '/oxguard/login?action=logout', function () {
+            var params = '&userid=' + ox.user_id + '&cid=' + ox.context_id;
+            $.get(ox.apiRoot + '/oxguard/login?action=logout' + params, function () {
                 window.oxguarddata = null;
             })
             .fail(function () {
