@@ -14,8 +14,10 @@ define('oxguard/settings', ['io.ox/core/extensions', 'gettext!oxguard/register']
     // Add settings for encryption to the Settings Page
     ext.point('io.ox/settings/pane').extend({
         title: gt('Guard Security Settings'),
-        index: 500,
-        id: 'oxguard'
+        index: 200,
+        id: 'oxguard',
+        advancedMode: false,
+        settingsgroup: 'main'
     });
 
 });
\ No newline at end of file
