@@ -15,7 +15,7 @@ define('oxguard/settings/pane',
             require(['oxguard/oxguard_core'], function (oxguard) {
                 oxguard.createKeys()
                 .done(function () {
-                    where.replaceWith(addSettings());
+                    $('.oxguard_settings').replaceWith(addSettings());
                 });
             });
         });
@@ -29,12 +29,20 @@ define('oxguard/settings/pane',
         $('<div class="oxguard_settings"/>')
         .append('<legend class="sectiontitle">' + gt('Password') + '</legend></br>')
         .append('<span> ' + gt('Change Guard Security Password.') + '</span><br/>');
-        
+        var newpass1 = $('<input type="password" name="newpass1"/>');
+        var td = $('<td>').append(newpass1);
+        var newpass2 = $('<input type="password" name="newpass2"/>');
+        var td2 = $('<td>').append(newpass2);
+        var hint = $('<td>');
         var passwordTable = $('<table/>')
-        .append('<tr><td><span>' + gt('Enter current Guard security password') + ': </span></td><td><input type="password" name="oldpass" /><td></tr>')
-        .append('<tr><td><span>' + gt('Enter new Guard security password') + ': </span></td><td><input type="password" name="newpass1"/><td></tr>')
-        .append('<tr><td><span>' + gt('Verify new Guard security password') + ':</span></td><td><input type="password" name="newpass2"/><td></tr>');
+        .append('<tr><td><span>' + gt('Enter current Guard security password') + ': </span></td><td><input type="password" name="oldpass" /><td><td></td></tr>')
+        .append($('<tr><td><span>' + gt('Enter new Guard security password') + ': </span></td></tr>').append(td).append(hint))
+        .append($('<tr><td><span>' + gt('Verify new Guard security password') + ':</span></td></tr>').append(td2).append('<td></td>'));
         var errorDiv = $('<div id="grdsettingerror" class="alert alert-info" style="display:none"/>');
+        require (['oxguard/core/passwords'], function (pass) {
+            pass.passwordCheck(newpass1, hint);
+            pass.passwordCompare(newpass2, newpass1);
+        });
         var passButton = $('<button type="button" class="btn btn-primary">' + gt('Change Guard security password') + '</button>');
         passButton.click(passChanged);
         
@@ -44,6 +52,9 @@ define('oxguard/settings/pane',
     
     
     function createPasswordReset() {
+        if (!window.oxguarddata.recovery) {  // If no recovery avail, then don't display reset button
+            return ('');
+        }
         var passheader =
             $('<div class="oxguard_settings"/>')
             .append('<legend class="sectiontitle">' + gt('Reset Guard security password') + '</legend></br>')
@@ -54,6 +65,47 @@ define('oxguard/settings/pane',
         
     }
     
+    function createDeleteRecovery() {
+        if (window.oxguarddata.settings.noDeleteRecovery || !window.oxguarddata.recovery) {
+            return('');
+        }
+        var header = 
+            $('<div class="oxguard_settings"/>')
+            .append('<legend class="sectiontitle">' + gt('Delete Password Recovery') + '</legend></br>')
+            .append('<b>' + gt('Advanced Users Only!') + '</b><br>')
+            .append('<span> ' + gt('Delete the password recovery.  The recovery is used to reset your password.  If you delete the recovery, you will not be able to reset your password if you forget it.  Changing your password will restore the recovery.') + '</span><br/>');
+        var deleteRecoveryButton = $('<button type="button" class="btn btn-primary">' + gt('Delete Password Recovery') + '</button>');
+        deleteRecoveryButton.click(doDeleteRecovery);
+        return (header.append(deleteRecoveryButton));
+    }
+    
+    function doDeleteRecovery() {
+        require (['oxguard/oxguard_core', 'io.ox/core/notifications'], function (core, notify) {
+            core.getPassword(gt('Please verify your password before deleting the recovery'))
+            .done (function (e) {
+                var data = {
+                        userid : ox.user_id,
+                        cid : ox.context_id,
+                        password : e
+                };
+                og_http.post(ox.apiRoot + '/oxguard/login?action=deleterecovery&session=' + ox.session, '', data)
+                .done (function () {
+                    notify.yell('success', gt('Recovery deleted'));
+                    window.oxguarddata.recovery = false;
+                    redraw();
+                })
+                .fail (function (e) {
+                    if (e.responseText.trim() === 'Bad password') {
+                        notify.yell('error', gt('Bad Password'));
+                    }
+                    else {
+                        notify.yell('error', e.responseText);
+                    }
+                });
+            });
+        });
+    }
+    
     function createSecondaryChange() {
         updateEmail();
         var emailheader =
@@ -114,7 +166,7 @@ define('oxguard/settings/pane',
             });
         }
     }
-    
+    /*
     function defaultGuard() {
         var defaultHeader =
             $('<div class="oxguard_settings"/>')
@@ -131,17 +183,18 @@ define('oxguard/settings/pane',
                 
             });
             defaultHeader.append(defaultbox).append(gt('Use Guard when composing a new email'));
-            if (window.oxguarddata.settings.defaultGuard !== undefined) {
-                defaultbox.prop('checked', window.oxguarddata.settings.defaultGuard);
+            if (window.oxguarddata.settings.pgpdefault !== undefined) {
+                defaultbox.prop('checked', window.oxguarddata.settings.pgpdefault);
             }
             return(defaultHeader);
     }
+
     
     function sendDefaults() {
         var defaultChecked = $('input[name="defaultguard"]').is(':checked');
-        window.oxguarddata.settings.defaultGuard = defaultChecked;
+        window.oxguarddata.settings.pgpdefault = defaultChecked;
         var data = {
-                defaultGuard : defaultChecked
+                pgpdefault : defaultChecked
         };
         var json = {
                 id : ox.user_id,
@@ -157,6 +210,7 @@ define('oxguard/settings/pane',
             });
         });
     }
+    */
     
     function showError(id) {
         $('#' + id).show();
@@ -386,13 +440,24 @@ define('oxguard/settings/pane',
     */
     function passChanged() {
 
-        if ($('input[name="newpass1"]').val() !== $('input[name="newpass2"]').val()) {
-            $('input[name="newpass2"]').css('background-color', 'salmon');
+        var newpass = $('input[name="newpass1"]');
+        var newpass2 = $('input[name="newpass2"]');
+        var min = window.oxguarddata.settings.min_password_length;
+        if (min !== undefined) {
+            if (newpass.val().length < min) {
+                $('#grdsettingerror').text(gt('New password must be at least %s characters long', min));
+                $('#grdsettingerror').show();
+                newpass.focus();
+                return;
+            }
+        }
+        if (newpass.val() !== newpass2.val()) {
+            newpass2.css('background-color', 'salmon');
             return;
         } else {
-            $('input[name="newpass2"]').css('background-color', 'white');
+            newpass2.css('background-color', 'white');
             var userdata = {
-                    newpass : $('input[name="newpass1"]').val(),
+                    newpass : newpass.val(),
                     oldpass : $('input[name="oldpass"]').val().trim(),
                     user_id : ox.user_id,
                     sessionID : ox.session,
@@ -416,11 +481,13 @@ define('oxguard/settings/pane',
                     $('#grdsettingerror').text(gt('New password must be at least %s characters long', data.minlength));
                 }
                 if (data.auth.length > 20) {
-                    $('#grdsettingerror').text(gt('Success'));
                     $('input[name="newpass1"]').val('');
                     $('input[name="newpass2"]').val('');
                     $('input[name="oldpass"]').val('');
                     window.oxguarddata.passcode = null;
+                    window.oxguarddata.recovery = data.recovery;
+                    redraw();
+                    $('#grdsettingerror').text(gt('Success'));
                 }
                 $('#grdsettingerror').show();
                 window.setTimeout(function () {
@@ -428,9 +495,13 @@ define('oxguard/settings/pane',
                 }, 10000);
             
             })
-            .fail(function () {
+            .fail(function (e) {
                 $('.og_wait').remove();
-                $('#grdsettingerror').text(gt('Failed to change password'));
+                var error = gt('Failed to change password');
+                if (e.responseText.trim() === 'Bad Password') {
+                    error = gt('Bad password');
+                }
+                $('#grdsettingerror').text(error);
                 $('#grdsettingerror').show();
             });
             return;
@@ -455,9 +526,14 @@ define('oxguard/settings/pane',
         }
     });
     
+    // Redraw
+    function redraw () {
+        $('#guard_settings').replaceWith(addSettings());
+    }
+    
     function addSettings () {
-        var holder = $('<div>').css('max-width', '800px');
+        var holder = $('<div id="guard_settings">').css('max-width', '800px');
         holder.append('<h1>' + gt('Guard Security Settings') + '</h1><br/>');
-        return (holder.append(defaultGuard()).append(createPasswordChange()).append(createPasswordReset()).append(createSecondaryChange()));
+        return (holder.append(createPasswordChange()).append(createPasswordReset()).append(createSecondaryChange()).append(createDeleteRecovery()));
     }
 });
